==> next-ft-api-client-2.0.4.tgz: package/src/content.js <==
'use strict';

var capiV2 = require('./utils/capi-v2');
var fetchres = require('fetchres');
var logger = require('ft-next-logger');
var catchNetworkErrors = require('./utils/catch-network-errors');

module.exports = function(opts) {
	var useElasticSearch = opts.useElasticSearch;
	var uuid = opts.uuid;
	var returnMany = true;
	var type = opts.type || 'unknown';
	if (!Array.isArray(uuid)) {
		uuid = [uuid];
		returnMany = false;
	}

	if (useElasticSearch) {
		return fetch('https://' + process.env.ELASTIC_SEARCH_HOST + '/v2_api_v2/item/_mget', {
				method: 'POST',
				body: JSON.stringify({ ids: uuid }),
				timeout: 3000
			})
			.catch(catchNetworkErrors)
			.then(function(response) {
				if (!response.ok) {
					logger.warn('Failed getting CAPIv2 content', {
						uuid: uuid,
						status: response.status
					});
				}
				return response;
			})
			.then(fetchres.json)
			.then(function(data) {
				var foundCount = 0;
				var docs = data.docs

					// Filter out any that haven't been found
					.filter(function(item) {
						if (item.found) {
							foundCount++;
							return true;
						}
					})
					.map(function(item) {
						return item._source;
					});
				if (returnMany) {
					return docs;
				}
				if (foundCount === 0) {
					throw new fetchres.BadServerResponseError(404);
				}
				return docs[0];
			});
	} else {
		return Promise.all(uuid.map(function(uuid) {
			return capiV2({
				uuid: uuid,
				path: '/' + (opts.metadata ? 'enriched' : '') + 'content/' + uuid,
				type: type
			});
		}))
			.then(function(items) {
				if (returnMany) {
					return items;
				}
				return items[0];
			});
	}
};

==> next-ft-api-client-3.7.0.tgz: package/src/content.js <==
'use strict';

var capiV2 = require('./utils/capi-v2');
var fetchres = require('fetchres');
var logger = require('ft-next-logger');
var eagerFetch = require('./utils/eager-fetch');

module.exports = function(opts) {
	var useElasticSearch = opts.useElasticSearch;
	var uuid = opts.uuid;
	var returnMany = true;
	var type = opts.type || 'unknown';
	if (!Array.isArray(uuid)) {
		uuid = [uuid];
		returnMany = false;
	}

	if (useElasticSearch) {
		return eagerFetch('https://' + process.env.ELASTIC_SEARCH_HOST + '/v2_api_v2/item/_mget', {
				method: 'POST',
				body: JSON.stringify({ ids: uuid }),
				timeout: 3000
			})
			.then(function(response) {
				if (!response.ok) {
					logger.warn('Failed getting CAPIv2 content', {
						uuid: uuid,
						status: response.status
					});
				}
				return response;
			})
			.then(fetchres.json)
			.then(function(data) {
				var foundCount = 0;
				var docs = data.docs

					// Filter out any that haven't been found
					.filter(function(item) {
						if (item.found) {
							foundCount++;
							return true;
						}
					})
					.map(function(item) {
						return item._source;
					});
				if (returnMany) {
					return docs;
				}
				if (foundCount === 0) {
					throw new fetchres.BadServerResponseError(404);
				}
				return docs[0];
			});
	}
	return Promise.all(uuid.map(function(uuid) {
		return capiV2({
			uuid: uuid,
			path: '/' + (opts.metadata ? 'enriched' : '') + 'content/' + uuid,
			type: type
		});
	}))
		.then(function(items) {
			if (returnMany) {
				return items;
			}
			return items[0];
		});
};
